@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2010-2013, Google Inc.
+# Copyright 2010-2014, Google Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,6 @@ import sys
 import zipfile
 
 
-
 class Error(Exception):
   """Base exception class for all android_util errors."""
 
@@ -240,18 +239,41 @@ class AndroidDevice(object):
   Attributes:
     serial: A string of serial. e.g. emulator-5554
             Serial can be seen by `adb devices` command.
+    android_home: A string pointing the root directory of the SDK.
   """
 
-  def __init__(self, serial):
+  def __init__(self, serial, android_home):
     """Initializes with serial string.
 
     Args:
       serial: A serial string, which is set to self.serial.
+      android_home: A string pointing the root directory of the SDK.
     """
     self.serial = serial
     # Don't access this property dicretly.
     # Use self._GetAvdName() instead.
     self._avd_name = None
+    self._android_home = android_home
+
+  def GetLogger(self):
+    """Gets logger instance.
+
+    Logger instance must not be a instance variable as
+    AndroidDevice must be able to be pickled.
+
+    Returns:
+      Logger instance.
+    """
+    # If we have avd_name, create own logger and return it.
+    # Don't keep this as an instance field.
+    # AndroidDevice must be able to be pickled.
+    if self._avd_name:
+      logger = logging.getLogger(self._avd_name)
+      logger.setLevel(logging.INFO)
+      return logger
+    # Otherwise return root logger.
+    # Root logger is used at _GetAvdName()'s first call.
+    return logging.getLogger()
 
   def WaitForDevice(self):
     """Equivalent to command "adb wait-for-device".
@@ -259,7 +281,7 @@ class AndroidDevice(object):
     Raises:
       AndroidUtilSubprocessError: wait-for-device is failed.
     """
-    args = [os.path.join(ANDROID_SDK_ROOT, 'platform-tools', 'adb'), '-s',
+    args = [os.path.join(self._android_home, 'platform-tools', 'adb'), '-s',
             self.serial, 'wait-for-device']
     if subprocess.call(args):
       raise AndroidUtilSubprocessError(
@@ -286,15 +308,17 @@ class AndroidDevice(object):
     Raises:
       AndroidUtilSubprocessError: Failed to run given command.
     """
-    args = ['adb', '-s', self.serial, 'shell']
+    args = [os.path.join(self._android_home, 'platform-tools', 'adb'),
+            '-s', self.serial, 'shell']
     args.extend(command)
-    logging.info('Running at %s: %s', self.serial, args)
+    self.GetLogger().info('Running at %s: %s', self.serial, args)
     process = subprocess.Popen(args, stdout=subprocess.PIPE)
     output, _ = process.communicate()
     if process.returncode != 0:
       raise AndroidUtilSubprocessError(
           'Failed to run the command: ' + ' '.join(command))
-    logging.info(output)
+    for i in output.splitlines():
+      self.GetLogger().info(i)
     return output
 
   def _GetAvdName(self):
@@ -312,40 +336,44 @@ class AndroidDevice(object):
     return self._RunCommand('getprop', key).rstrip()
 
   @staticmethod
-  def GetDevices():
+  def GetDevices(android_home):
     """Gets all the available devices via adb.
 
     The devices which are accessible from adb and of which status is
     'device' or 'offline' are returned.
     'unknown' devices are not included becuase it will never be accessible.
 
+    Args:
+      android_home: A string pointing the root directory of the SDK.
+
     Raises:
       AndroidUtilSubprocessError: when `adb` commands fails.
     Returns:
       A list of AndroidDevice.
     """
-    args = ['adb', 'devices']
+    args = [os.path.join(android_home, 'platform-tools', 'adb'), 'devices']
     logging.info('Running: %s', args)
     process = subprocess.Popen(args, stdout=subprocess.PIPE)
     output, _ = process.communicate()
     if process.returncode != 0:
       raise AndroidUtilSubprocessError(
           'Failed to run the command: ' + ' '.join(args))
-    logging.info(output)
+    for i in output.splitlines():
+      logging.info(i)
     result = []
     # offline is used for such emulator processes which have just been launched.
     regex = re.compile(r'(.*?)\s+(?:device|offline)$')
     for line in output.splitlines():
       match = regex.match(line)
       if match:
-        result.append(AndroidDevice(match.group(1)))
+        result.append(AndroidDevice(match.group(1), android_home))
     return result
 
 
 class Emulator(object):
   """An emulator and emulator related stuff."""
 
-  def __init__(self, android_sdk_home, avd_name):
+  def __init__(self, android_sdk_home, avd_name, android_home):
     """Create an Emulator instance.
 
     After instantiation, an emulator process is not lauched.
@@ -354,11 +382,13 @@ class Emulator(object):
     SDK home by SetUpTestingSdkHomeDirectory before creating an Emulator
     instance.
     Args:
-      android_sdk_home: Path to android sdk home.
+      android_sdk_home: Path to android sdk home, containing .android directory.
       avd_name: Name of an avd to use.
+      android_home: A string pointing the root directory of the SDK.
     """
     self._android_sdk_home = android_sdk_home
     self._avd_name = avd_name
+    self._android_home = android_home
     self._avd_dir = os.path.join(android_sdk_home, '.android',
                                  'avd', '%s.avd' % avd_name)
     self._avd_properties = GetAvdProperties(android_sdk_home, avd_name)
@@ -391,7 +421,7 @@ class Emulator(object):
     logging.info('hw.cpu.arch is %s so using %s', hw_cpu_arch, emulator)
 
     args = [
-        os.path.join(ANDROID_SDK_ROOT, 'tools', emulator),
+        os.path.join(self._android_home, 'tools', emulator),
         '-avd', self._avd_name,
         '-port', str(self._port_number),
         '-no-window',  # For headless environment.
@@ -399,8 +429,10 @@ class Emulator(object):
         '-verbose',
     ]
     logging.info('Launching an emulator; %s', args)
+    # ANDROID_SDK_HOME: Where .avd file are located.
+    # ANDROID_SDK_ROOT: Where SDK is installed.
     env = {'ANDROID_SDK_HOME': self._android_sdk_home,
-           'ANDROID_SDK_ROOT': ANDROID_SDK_ROOT}
+           'ANDROID_SDK_ROOT': self._android_home}
     self._process = subprocess.Popen(args, env=env)
     if self._process.poll() is not None:
       raise AndroidUtilSubprocessError('Emulator launch fails.')
@@ -418,7 +450,7 @@ class Emulator(object):
           'Emulator process for %s has been launched already '
           'so SD card creation fails.' % self.serial)
     sdcard_path = os.path.join(self._avd_dir, 'sdcard.img')
-    args = [os.path.join(ANDROID_SDK_ROOT, 'tools', 'mksdcard'),
+    args = [os.path.join(self._android_home, 'tools', 'mksdcard'),
             str(size_bytes), sdcard_path]
     logging.info('Creating SD card: %s', args)
     if subprocess.call(args):
@@ -447,8 +479,8 @@ class Emulator(object):
       raise AndroidUtilSubprocessError(
           'Copying %s into SD card fails' % host_src_dir)
 
-  def GetAndroidDevice(self):
-    return AndroidDevice(self.serial)
+  def GetAndroidDevice(self, android_home):
+    return AndroidDevice(self.serial, android_home)
 
   def Terminate(self):
     """Terminate the process.
@@ -463,14 +495,16 @@ class Emulator(object):
     self._process = None
 
 
-def GetAvailableEmulatorPorts():
+def GetAvailableEmulatorPorts(android_home):
   """Returns a list of ports which are available for an emulator.
 
   Returned port can be passed to Launch method as port parameter.
+  Args:
+    android_home: A string pointing the root directory of the SDK.
   Returns:
     List of available ports.
   """
-  args = [os.path.join(ANDROID_SDK_ROOT, 'platform-tools', 'adb'), 'devices']
+  args = [os.path.join(android_home, 'platform-tools', 'adb'), 'devices']
   process = subprocess.Popen(args, stdout=subprocess.PIPE)
   (devices_result, _) = process.communicate()
   used_ports = set(int(port) for port
@@ -498,7 +532,8 @@ def _GetFixedAvdIni(original_file, ini_file_path):
   return ''.join(result)
 
 
-def _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name):
+def _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name,
+                                   android_home):
   """Copy pregenerated files if possible.
 
   Currently only userdata-qemu.img is copied.
@@ -508,8 +543,10 @@ def _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name):
   our expectation and can be created by CreateBlankSdCard method.
 
   Args:
-    dest_android_sdk_home: Path to Android SDK home
+    dest_android_sdk_home: Path to Android SDK home, which contains .android
+                           directory.
     avd_name: Name of AVD.
+    android_home: Root direcotry of the SDK.
   Returns:
     True if pregenerated file(s) is/are successfully copied.
   """
@@ -518,7 +555,7 @@ def _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name):
   # Expecting image.sysdir.1 points system image.
   system_image_relative = GetAvdProperties(
       dest_android_sdk_home, avd_name)['image.sysdir.1']
-  system_image_dir = os.path.join(ANDROID_SDK_ROOT, system_image_relative)
+  system_image_dir = os.path.join(android_home, system_image_relative)
   userdata_qemu_path = os.path.join(system_image_dir, 'pregenerated',
                                     'userdata-qemu.img')
   if os.path.exists(userdata_qemu_path):
@@ -542,7 +579,8 @@ def _RewriteIni(ini_file_path, open_read=open, open_write=open):
 
 
 def SetUpTestingSdkHomeDirectory(template_android_sdk_home,
-                                 dest_android_sdk_home):
+                                 dest_android_sdk_home,
+                                 android_home):
   """Sets up sdk home directory to minimum required level.
 
   This method copies files from template directory to target.
@@ -556,6 +594,7 @@ def SetUpTestingSdkHomeDirectory(template_android_sdk_home,
     template_android_sdk_home: path to template android sdk home directory.
     dest_android_sdk_home: path to newly created sdk home directory basing on
         template_android_sdk_home
+    android_home: A string pointing the root directory of the SDK.
   """
   # Copy entire tree.
   if os.path.exists(dest_android_sdk_home):
@@ -568,7 +607,8 @@ def SetUpTestingSdkHomeDirectory(template_android_sdk_home,
   for ini_file_path in glob.glob(os.path.join(target_avd_dir, '*.ini')):
     _RewriteIni(ini_file_path)
     avd_name = os.path.splitext(os.path.basename(ini_file_path))[0]
-    _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name)
+    _CopyPregeneratedFileToSdkHome(dest_android_sdk_home, avd_name,
+                                   android_home)
 
 
 def GetAvdNames(android_sdk_home):
