@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2014, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -76,10 +76,6 @@ class ClientMock : public client::ClientInterface {
   bool LaunchTool(const string &mode, const string &extra_arg);
   bool LaunchToolWithProtoBuf(const commands::Output &output);
   bool OpenBrowser(const string &url);
-  bool StartCloudSync();
-  bool GetCloudSyncStatus(commands::CloudSyncStatus *cloud_sync_status);
-  void set_output_GetCloudSyncStatus(
-      const commands::CloudSyncStatus &cloud_sync_status);
 
   void ClearFunctionCounter();
   void SetBoolFunctionReturn(string func_name, bool value);
@@ -110,8 +106,6 @@ class ClientMock : public client::ClientInterface {
   map<string, commands::Output> outputs_;
 
   config::Config called_config_;
-
-  commands::CloudSyncStatus cloud_sync_status_;
 };
 }  // namespace client
 }  // namespace mozc
