@@ -1,29 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0">
-<context>
-    <name>AuthDialog</name>
-    <message>
-        <location filename="auth_dialog.ui" line="32"/>
-        <source>Get Auth code</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="78"/>
-        <source>1. Click the following button to open permission page.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="91"/>
-        <source>2. Allow the access in the page, and copy&amp;paste the auth code in the box below.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="123"/>
-        <source>Open Browser...</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -44,7 +21,6 @@
     <message>
         <location filename="config_dialog.ui" line="185"/>
         <location filename="config_dialog.ui" line="192"/>
-        <location filename="config_dialog.ui" line="1279"/>
         <source>Customize...</source>
         <translation></translation>
     </message>
@@ -141,7 +117,7 @@
     <message>
         <location filename="config_dialog.ui" line="800"/>
         <source>Show input mode indicator near the cursor</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="config_dialog.ui" line="809"/>
@@ -174,58 +150,53 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1308"/>
-        <source>latest sync</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.ui" line="1340"/>
+        <location filename="config_dialog.ui" line="1225"/>
         <source>Enable Cloud handwriting recognition</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1356"/>
-        <source>Other Cloud based feature</source>
+        <location filename="config_dialog.ui" line="1241"/>
+        <source>Cloud handwriting recognition</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1378"/>
+        <location filename="config_dialog.ui" line="1263"/>
         <source>Misc</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1678"/>
+        <location filename="config_dialog.ui" line="1563"/>
         <source>Startup</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1716"/>
+        <location filename="config_dialog.ui" line="1601"/>
         <source>Start conversion engine on login</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1809"/>
+        <location filename="config_dialog.ui" line="1694"/>
         <source>Logging level (debug only)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1765"/>
+        <location filename="config_dialog.ui" line="1650"/>
         <source>Logging</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1562"/>
+        <location filename="config_dialog.ui" line="1447"/>
         <source>Administration</source>
         <translation></translation>
     </message>
     <message>
         <location filename="config_dialog.ui" line="1162"/>
-        <location filename="config_dialog.ui" line="1619"/>
+        <location filename="config_dialog.ui" line="1504"/>
         <source>Settings...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1606"/>
+        <location filename="config_dialog.ui" line="1491"/>
         <source>Dictionary preloading and UAC settings</source>
         <translation></translation>
     </message>
@@ -269,11 +240,6 @@
         <source>character entered by ¥ key</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="config_dialog.ui" line="1266"/>
-        <source>Start Sync</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="config_dialog.ui" line="287"/>
         <source>Clear personalization data</source>
@@ -400,32 +366,22 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1228"/>
-        <source>Sync</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.ui" line="1321"/>
-        <source>Mozc can securely syncs your settings and a user sync-dictionary among different machines. Synced data can be cleared by &lt;a href=&quot;https://www.google.com/settings/dashboard&quot;&gt;Google Dashboard&lt;/a&gt;.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.ui" line="1500"/>
+        <location filename="config_dialog.ui" line="1385"/>
         <source>Check if Mozc is the default IME on startup</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1453"/>
+        <location filename="config_dialog.ui" line="1338"/>
         <source>Default IME</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1510"/>
+        <location filename="config_dialog.ui" line="1395"/>
         <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1890"/>
+        <location filename="config_dialog.ui" line="1775"/>
         <source>Reset to defaults</source>
         <translation></translation>
     </message>
@@ -501,29 +457,6 @@
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>SyncCustomizeDialog</name>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="26"/>
-        <source>Dialog</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="54"/>
-        <source>Sync everything</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="70"/>
-        <source>config</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="77"/>
-        <source>user dictionary</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>mozc::gui::CharacterFormEditor</name>
     <message>
@@ -565,301 +498,208 @@
 <context>
     <name>mozc::gui::ConfigDialog</name>
     <message>
-        <location filename="config_dialog.cc" line="137"/>
+        <location filename="config_dialog.cc" line="124"/>
         <source>Custom keymap</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="138"/>
+        <location filename="config_dialog.cc" line="125"/>
         <source>ATOK</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="139"/>
+        <location filename="config_dialog.cc" line="126"/>
         <source>MS-IME</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="140"/>
+        <location filename="config_dialog.cc" line="127"/>
         <source>Kotoeri</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="146"/>
+        <location filename="config_dialog.cc" line="133"/>
         <source>Romaji</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="147"/>
+        <location filename="config_dialog.cc" line="134"/>
         <source>Kana</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="151"/>
+        <location filename="config_dialog.cc" line="138"/>
         <source>Romaji (switchable)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="152"/>
+        <location filename="config_dialog.cc" line="139"/>
         <source>Kana (switchable)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="155"/>
-        <location filename="config_dialog.cc" line="171"/>
+        <location filename="config_dialog.cc" line="142"/>
+        <location filename="config_dialog.cc" line="158"/>
         <source>Follow input mode</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="156"/>
-        <location filename="config_dialog.cc" line="172"/>
+        <location filename="config_dialog.cc" line="143"/>
+        <location filename="config_dialog.cc" line="159"/>
         <source>Fullwidth</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="157"/>
-        <location filename="config_dialog.cc" line="173"/>
+        <location filename="config_dialog.cc" line="144"/>
+        <location filename="config_dialog.cc" line="160"/>
         <source>Halfwidth</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="159"/>
+        <location filename="config_dialog.cc" line="146"/>
         <source>No shortcut</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="160"/>
+        <location filename="config_dialog.cc" line="147"/>
         <source>1 -- 9</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="161"/>
+        <location filename="config_dialog.cc" line="148"/>
         <source>A -- L</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="163"/>
+        <location filename="config_dialog.cc" line="150"/>
         <source>Yes</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="164"/>
+        <location filename="config_dialog.cc" line="151"/>
         <source>Yes (don&apos;t record new data)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="165"/>
+        <location filename="config_dialog.cc" line="152"/>
         <source>No</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="167"/>
+        <location filename="config_dialog.cc" line="154"/>
         <source>Off</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="168"/>
+        <location filename="config_dialog.cc" line="155"/>
         <source>Alphanumeric</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="169"/>
+        <location filename="config_dialog.cc" line="156"/>
         <source>Katakana</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="174"/>
+        <location filename="config_dialog.cc" line="161"/>
         <source>Direct input</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="176"/>
+        <location filename="config_dialog.cc" line="163"/>
         <source>0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="177"/>
+        <location filename="config_dialog.cc" line="164"/>
         <source>1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="178"/>
+        <location filename="config_dialog.cc" line="165"/>
         <source>2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="180"/>
+        <location filename="config_dialog.cc" line="167"/>
         <source>Yen Sign Â¥</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="181"/>
+        <location filename="config_dialog.cc" line="168"/>
         <source>Backslash \</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="306"/>
+        <location filename="config_dialog.cc" line="283"/>
         <source>Dictionary preloading</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="71"/>
+        <location filename="config_dialog.cc" line="68"/>
         <source>Mozc Preferences</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="404"/>
+        <location filename="config_dialog.cc" line="360"/>
         <source>Failed to get current config values.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="423"/>
+        <location filename="config_dialog.cc" line="379"/>
         <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="436"/>
+        <location filename="config_dialog.cc" line="392"/>
         <source>Romaji/Kana setting is enabled from new applications.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="447"/>
+        <location filename="config_dialog.cc" line="403"/>
         <source>Input mode indicator setting is enabled from new applications.</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="455"/>
+        <location filename="config_dialog.cc" line="411"/>
         <source>Failed to update config</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="637"/>
-        <source>Checking sync status</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="639"/>
-        <location filename="config_dialog.cc" line="1153"/>
-        <source>Sync is not enabled</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="779"/>
+        <location filename="config_dialog.cc" line="722"/>
         <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="793"/>
-        <location filename="config_dialog.cc" line="815"/>
+        <location filename="config_dialog.cc" line="736"/>
+        <location filename="config_dialog.cc" line="758"/>
         <source>Mozc Converter is not running. Settings were not saved.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="803"/>
+        <location filename="config_dialog.cc" line="746"/>
         <source>Do you want to clear all history data?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="825"/>
+        <location filename="config_dialog.cc" line="768"/>
         <source>Do you want to clear unused history data?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="837"/>
+        <location filename="config_dialog.cc" line="780"/>
         <source>Mozc Converter is not running. Operation was not executed.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="933"/>
+        <location filename="config_dialog.cc" line="853"/>
         <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
  - Personalization data
  - Input history
- - Sync settings
  - Usage statistics and crash reports
  - Administrator settings</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="config_dialog.cc" line="988"/>
-        <source>Stop Sync</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="990"/>
-        <source>Start Sync</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1006"/>
-        <source>Stop sync and reset the auth token</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1007"/>
-        <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
-Do you really want to continue?</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1100"/>
-        <source>Not synced yet</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1104"/>
-        <source>Last synced time: </source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1143"/>
-        <source>Waiting for server to be ready</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1148"/>
-        <source>During synchronization</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1169"/>
-        <source>Authorization failed.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1172"/>
-        <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1176"/>
-        <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1180"/>
-        <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1184"/>
-        <source>Unknown error was found.</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1196"/>
-        <source>Authorization error</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1201"/>
-        <source>Dictionary sync error</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1204"/>
-        <source>Unknown sync error</source>
-        <translation></translation>
-    </message>
 </context>
 <context>
     <name>mozc::gui::GenericTableEditorDialog</name>
