@@ -1,29 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ja_JP">
-<context>
-    <name>AuthDialog</name>
-    <message>
-        <location filename="auth_dialog.ui" line="32"/>
-        <source>Get Auth code</source>
-        <translation>認証コードを取得</translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="78"/>
-        <source>1. Click the following button to open permission page.</source>
-        <translation>1. このボタンをクリックすると認証ページが開きます。</translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="91"/>
-        <source>2. Allow the access in the page, and copy&amp;paste the auth code in the box below.</source>
-        <translation>2. 認証すると表示される認証コードを下にあるテキストボックスに貼り付けてください。</translation>
-    </message>
-    <message>
-        <location filename="auth_dialog.ui" line="123"/>
-        <source>Open Browser...</source>
-        <translation>ブラウザを開く...</translation>
-    </message>
-</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -31,11 +8,6 @@
         <source>Mozc Settings</source>
         <translation>Mozc プロパティ</translation>
     </message>
-    <message>
-        <location filename="config_dialog.ui" line="1321"/>
-        <source>Mozc can securely syncs your settings and a user sync-dictionary among different machines. Synced data can be cleared by &lt;a href=&quot;https://www.google.com/settings/dashboard&quot;&gt;Google Dashboard&lt;/a&gt;.</source>
-        <translation>設定や同期用ユーザー辞書を、異なるコンピュータ間で安全に同期します。同期済みのデータは &lt;a href=&quot;https://www.google.com/settings/dashboard&quot;&gt;Google ダッシュボード&lt;/a&gt; から削除できます。</translation>
-    </message>
     <message>
         <location filename="config_dialog.ui" line="57"/>
         <source>General</source>
@@ -79,7 +51,6 @@
     <message>
         <location filename="config_dialog.ui" line="185"/>
         <location filename="config_dialog.ui" line="192"/>
-        <location filename="config_dialog.ui" line="1279"/>
         <source>Customize...</source>
         <translation>編集...</translation>
     </message>
@@ -108,16 +79,6 @@
         <source>Cloud</source>
         <translation>クラウド</translation>
     </message>
-    <message>
-        <location filename="config_dialog.ui" line="1228"/>
-        <source>Sync</source>
-        <translation>同期</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.ui" line="1266"/>
-        <source>Start Sync</source>
-        <translation>同期する</translation>
-    </message>
     <message>
         <location filename="config_dialog.ui" line="272"/>
         <source>Dictionary</source>
@@ -344,53 +305,48 @@
         <translation>プレゼンテーションモード</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1308"/>
-        <source>latest sync</source>
-        <translation>最終同期時刻</translation>
+        <location filename="config_dialog.ui" line="1241"/>
+        <source>Cloud handwriting recognition</source>
+        <translation>クラウド手書き文字認識</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1356"/>
-        <source>Other Cloud based feature</source>
-        <translation>その他のクラウド機能</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.ui" line="1378"/>
+        <location filename="config_dialog.ui" line="1263"/>
         <source>Misc</source>
         <translation>その他</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1678"/>
+        <location filename="config_dialog.ui" line="1563"/>
         <source>Startup</source>
         <translation>スタートアップ</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1716"/>
+        <location filename="config_dialog.ui" line="1601"/>
         <source>Start conversion engine on login</source>
         <translation>ログイン時に変換エンジンプログラムを起動する</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1809"/>
+        <location filename="config_dialog.ui" line="1694"/>
         <source>Logging level (debug only)</source>
         <translation>ログレベル（デバッグ）</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1765"/>
+        <location filename="config_dialog.ui" line="1650"/>
         <source>Logging</source>
         <translation>ログ</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1562"/>
+        <location filename="config_dialog.ui" line="1447"/>
         <source>Administration</source>
         <translation>管理</translation>
     </message>
     <message>
         <location filename="config_dialog.ui" line="1162"/>
-        <location filename="config_dialog.ui" line="1619"/>
+        <location filename="config_dialog.ui" line="1504"/>
         <source>Settings...</source>
         <translation>設定変更...</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1606"/>
+        <location filename="config_dialog.ui" line="1491"/>
         <source>Dictionary preloading and UAC settings</source>
         <translation>オンメモリ辞書とUACの設定</translation>
     </message>
@@ -406,27 +362,27 @@
 Mozcの機能向上に役立てる（再ログイン後に変更は完了します）</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1340"/>
+        <location filename="config_dialog.ui" line="1225"/>
         <source>Enable Cloud handwriting recognition</source>
         <translation>クラウド手書き文字認識を有効にする</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1500"/>
+        <location filename="config_dialog.ui" line="1385"/>
         <source>Check if Mozc is the default IME on startup</source>
         <translation>起動時に Mozcが既定の IME であるか確認する</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1510"/>
+        <location filename="config_dialog.ui" line="1395"/>
         <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
         <translation>ホットキー(Ctrl+Shift)による IME の切り替えを無効化する</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1453"/>
+        <location filename="config_dialog.ui" line="1338"/>
         <source>Default IME</source>
         <translation>既定の IME</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1890"/>
+        <location filename="config_dialog.ui" line="1775"/>
         <source>Reset to defaults</source>
         <translation>初期値に戻す</translation>
     </message>
@@ -502,29 +458,6 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
         <translation>アルファベット</translation>
     </message>
 </context>
-<context>
-    <name>SyncCustomizeDialog</name>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="26"/>
-        <source>Dialog</source>
-        <translation>同期の詳細設定</translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="54"/>
-        <source>Sync everything</source>
-        <translation>全て同期する</translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="70"/>
-        <source>config</source>
-        <translation>設定</translation>
-    </message>
-    <message>
-        <location filename="sync_customize_dialog.ui" line="77"/>
-        <source>user dictionary</source>
-        <translation>ユーザー辞書</translation>
-    </message>
-</context>
 <context>
     <name>mozc::gui::CharacterFormEditor</name>
     <message>
@@ -566,304 +499,209 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
 <context>
     <name>mozc::gui::ConfigDialog</name>
     <message>
-        <location filename="config_dialog.cc" line="140"/>
+        <location filename="config_dialog.cc" line="127"/>
         <source>Kotoeri</source>
         <translation>ことえり</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="137"/>
+        <location filename="config_dialog.cc" line="124"/>
         <source>Custom keymap</source>
         <translation>カスタム</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="71"/>
+        <location filename="config_dialog.cc" line="68"/>
         <source>Mozc Preferences</source>
         <translation>Mozc 環境設定</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="138"/>
+        <location filename="config_dialog.cc" line="125"/>
         <source>ATOK</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="139"/>
+        <location filename="config_dialog.cc" line="126"/>
         <source>MS-IME</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="146"/>
+        <location filename="config_dialog.cc" line="133"/>
         <source>Romaji</source>
         <translation>ローマ字入力</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="147"/>
+        <location filename="config_dialog.cc" line="134"/>
         <source>Kana</source>
         <translation>かな入力</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="151"/>
+        <location filename="config_dialog.cc" line="138"/>
         <source>Romaji (switchable)</source>
         <translation>ローマ字入力 (切替可)</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="152"/>
+        <location filename="config_dialog.cc" line="139"/>
         <source>Kana (switchable)</source>
         <translation>かな入力 (切替可)</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="155"/>
-        <location filename="config_dialog.cc" line="171"/>
+        <location filename="config_dialog.cc" line="142"/>
+        <location filename="config_dialog.cc" line="158"/>
         <source>Follow input mode</source>
         <translation>入力モードに従う</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="156"/>
-        <location filename="config_dialog.cc" line="172"/>
+        <location filename="config_dialog.cc" line="143"/>
+        <location filename="config_dialog.cc" line="159"/>
         <source>Fullwidth</source>
         <translation>全角</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="157"/>
-        <location filename="config_dialog.cc" line="173"/>
+        <location filename="config_dialog.cc" line="144"/>
+        <location filename="config_dialog.cc" line="160"/>
         <source>Halfwidth</source>
         <translation>半角</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="159"/>
+        <location filename="config_dialog.cc" line="146"/>
         <source>No shortcut</source>
         <translation>なし</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="160"/>
+        <location filename="config_dialog.cc" line="147"/>
         <source>1 -- 9</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="161"/>
+        <location filename="config_dialog.cc" line="148"/>
         <source>A -- L</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="163"/>
+        <location filename="config_dialog.cc" line="150"/>
         <source>Yes</source>
         <translation>有効</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="164"/>
+        <location filename="config_dialog.cc" line="151"/>
         <source>Yes (don&apos;t record new data)</source>
         <translation>有効（新規学習はしない）</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="165"/>
+        <location filename="config_dialog.cc" line="152"/>
         <source>No</source>
         <translation>無効</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="167"/>
+        <location filename="config_dialog.cc" line="154"/>
         <source>Off</source>
         <translation>オフ</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="168"/>
+        <location filename="config_dialog.cc" line="155"/>
         <source>Alphanumeric</source>
         <translation>英数字</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="169"/>
+        <location filename="config_dialog.cc" line="156"/>
         <source>Katakana</source>
         <translation>カタカナ</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="174"/>
+        <location filename="config_dialog.cc" line="161"/>
         <source>Direct input</source>
         <translation>直接入力</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="176"/>
+        <location filename="config_dialog.cc" line="163"/>
         <source>0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="177"/>
+        <location filename="config_dialog.cc" line="164"/>
         <source>1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="178"/>
+        <location filename="config_dialog.cc" line="165"/>
         <source>2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="180"/>
+        <location filename="config_dialog.cc" line="167"/>
         <source>Yen Sign Â¥</source>
         <translation>円記号(¥)</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="181"/>
+        <location filename="config_dialog.cc" line="168"/>
         <source>Backslash \</source>
         <translation>バックスラッシュ(\)</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="404"/>
+        <location filename="config_dialog.cc" line="360"/>
         <source>Failed to get current config values.</source>
         <translation>設定の取得に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="436"/>
+        <location filename="config_dialog.cc" line="392"/>
         <source>Romaji/Kana setting is enabled from new applications.</source>
         <translation>ローマ字・かな入力の設定は新しいアプリケーションから有効になります。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="447"/>
+        <location filename="config_dialog.cc" line="403"/>
         <source>Input mode indicator setting is enabled from new applications.</source>
         <translation>入力モード表示の設定は新しいアプリケーションから有効になります。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="637"/>
-        <source>Checking sync status</source>
-        <translation>同期状態を確認する</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="639"/>
-        <location filename="config_dialog.cc" line="1153"/>
-        <source>Sync is not enabled</source>
-        <translation>同期機能：オフ</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="793"/>
-        <location filename="config_dialog.cc" line="815"/>
+        <location filename="config_dialog.cc" line="736"/>
+        <location filename="config_dialog.cc" line="758"/>
         <source>Mozc Converter is not running. Settings were not saved.</source>
         <translation>変換サーバが反応していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="933"/>
+        <location filename="config_dialog.cc" line="853"/>
         <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
  - Personalization data
  - Input history
- - Sync settings
  - Usage statistics and crash reports
  - Administrator settings</source>
         <translation>この機能を実行すると Mozcの設定が標準状態に戻ります。実行しますか？ 以下の設定はリセットされません。
  - 学習履歴
  - 入力履歴
- - 同期設定
  - 使用統計と障害レポート
  - 管理者用設定</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="988"/>
-        <source>Stop Sync</source>
-        <translation>同期の解除</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="990"/>
-        <source>Start Sync</source>
-        <translation>同期する</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1006"/>
-        <source>Stop sync and reset the auth token</source>
-        <translation>同期の解除と認証コードのクリア</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1007"/>
-        <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
-Do you really want to continue?</source>
-        <translation>同期の解除と認証コードのクリアを行います。同期を再開するには、新しい認証コードを取得する必要があります。
-実行しますか？</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1100"/>
-        <source>Not synced yet</source>
-        <translation>同期されていません</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1104"/>
-        <source>Last synced time: </source>
-        <translation>最終同期時刻: </translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1143"/>
-        <source>Waiting for server to be ready</source>
-        <translation>サーバの状態を確認しています.. この処理は最大2分かかります</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1169"/>
-        <source>Authorization failed.</source>
-        <translation>認証に失敗しました。</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1172"/>
-        <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
-        <translation>単語数の上限を超えたため同期用辞書をセーブできません。</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1176"/>
-        <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
-        <translation>ファイルサイズの上限を超えたため同期用辞書をセーブできません。</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1180"/>
-        <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
-        <translation>同期用辞書の数が上限を超えたため辞書をセーブできません。</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1184"/>
-        <source>Unknown error was found.</source>
-        <translation>未知のエラーです。</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1196"/>
-        <source>Authorization error</source>
-        <translation>認証失敗</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1201"/>
-        <source>Dictionary sync error</source>
-        <translation>辞書同期エラー</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1204"/>
-        <source>Unknown sync error</source>
-        <translation>未知の同期エラー</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="1148"/>
-        <source>During synchronization</source>
-        <translation>同期中です</translation>
-    </message>
-    <message>
-        <location filename="config_dialog.cc" line="306"/>
+        <location filename="config_dialog.cc" line="283"/>
         <source>Dictionary preloading</source>
         <translation>オンメモリ辞書の設定</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="423"/>
+        <location filename="config_dialog.cc" line="379"/>
         <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
         <translation>有効なキー設定がありません。カスタム キーマップを選択した場合は、キーマップを編集する必要があります。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="455"/>
+        <location filename="config_dialog.cc" line="411"/>
         <source>Failed to update config</source>
         <translation>設定の反映に失敗しました</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="779"/>
+        <location filename="config_dialog.cc" line="722"/>
         <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
         <translation>学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="837"/>
+        <location filename="config_dialog.cc" line="780"/>
         <source>Mozc Converter is not running. Operation was not executed.</source>
         <translation>Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="803"/>
+        <location filename="config_dialog.cc" line="746"/>
         <source>Do you want to clear all history data?</source>
         <translation>すべての入力履歴が削除されます。実行しますか？</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="825"/>
+        <location filename="config_dialog.cc" line="768"/>
         <source>Do you want to clear unused history data?</source>
         <translation>サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
     </message>
